/**
* Provides JAVA and Jython classes that enable composition of benchmark-driven
* systems which usually require multiple runs of benchmarking and interaction
* with the benchmark results.
* <p>
* The main purpose of this package is to ease implementation of a high-level
* driver that requires multiple benchmark invocations with the Cetus compiler
* being the core part of the benchmark. We have been using various such systems
* so far and found that substantial tasks within those systems share the same
* requirement -- multiple invocations of program translation, compilation, and
* execution. However, most of the systems are not reusable in different contexts
* with the reason being:
* <ul>
* <li> Different systems require different customized hard-wired Cetus drivers
* <li> Different systems are implemented with different languages
* <li> The systems depends too much on a specific version of Cetus
* </ul>
* <p>
* We chose Jython/JAVA as implementation language since it helps overcome some
* of the above restrictions and provides more flexibilities. For example, users
* can easily customize drivers without much effort since they can just call
* any individual passes; they can choose their preferred way of instrumenting
* the code or collecting benchmark result.
* <p>
* The tools assume the high-level drivers drive multiple benchmarks based on
* two basic entities - option and metric. Option is an input to a single
* benchmark invocation, which contains comprehensive environment for the
* benchmark. Metric is an output from a single benchmark invocation, which
* describes the result of the benchmark. The key features of this
* package are that it provides a simple format for option and metric, and that
* it simplifies exchange of those input and output. These two entities are
* provided as JAVA classes, and accessing/modifying these objects are easily
* done both in JAVA and in Jython.
* <p>
* The following base modules are provided at this point:
* <ul>
* <li> {@link benchmark.CetusDriver}: JAVA class that exposes driver internals
*      and IR
* <li> {@link benchmark.Option}: JAVA class that provides container for
*      <b>Option</b>
* <li> {@link benchmark.Metric}: JAVA class that provides container for
*      <b>Metric</b>
* <li> benchmarktool: Jython module that provides complete tool set for running
*      a single cycle of benchmark with an {@link benchmark.Option} object.
*/
package benchmark;
